/*
 * AFPT - Arduino Fácil Para Todos
 * 
 * Prueba Arduino ZERO + KY009
 * 
 * Recordar conectar el Arduino ZERO mediante el puerto de programación, el mas cercano al led
 * de Debug. Solo a traves de este puerto podemos mandar mensajes al visor serie del IDE
 * 
 * Modulo_KY-009.ino
 * 
 * www.fantasystudios.es/arduino
 * 
 * Creado el 29 de Abril de 2020
 * Por Manuel Peláez
 * 
 */

//Pines I/O
int pin_G = 3;                  //definimos el pin de salida al LED de color verde
int pin_R = 4;                  //definimos el pin de salida al LED de color rojo
int pin_B = 5;                  //definimos el pin de salida al LED de color azul

//Arrays con los valores por los que pasaran todos los LED en los 9 bloques
int led_rojo[11] = {0,0,1,1,1,0,0,1,1,1,0};    //Valores por los que pasara el LED rojo
int led_verde[11]= {0,1,1,0,0,0,1,1,1,0,0};    //Valores por los que pasara el LED verde
int led_azul[11] = {0,0,0,0,1,1,1,1,0,0,0};    //Valores por los que pasara el LED azul
String color[11] = {"Negro","Verde","Amarillo","Rojo","Magenta",        //Nombres de los
                    "Azul","Cyan","Blanco","Amarillo","Rojo","Negro"};  //colores


//Variables del sistema
int rapidez = 10;       //valor que marca la velocidad del cambio entre los colores
int ciclo;              //variable que almacena el "ciclo" o bucle que estamos haciendo
int a;                  //variable usada en los bucles for



void setup() {
  // put your setup code here, to run once:
  pinMode(pin_G, OUTPUT);       //configuramos el pin del verde como salida digital
  pinMode(pin_R, OUTPUT);       //configuramos el pin del rojo como salida digital
  pinMode(pin_B, OUTPUT);       //configuramos el pin del azul como salida digital

  Serial.begin(9600);           //inicializo el puerto serie USB
}


void loop() {
  // put your main code here, to run repeatedly:

  /* Descripcion del programa
  Vamos a encender todos los colores disponibles funciendolos desde:
  - Negro -> Verde -> Amarillo -> Rojo -> Magenta -> Azul -> Cyan -> 
    Blanco -> Amarillo -> Rojo -> Negro
    
  ¡¡OJO!! - Este programa tiene una limitación para hacerlo mas sencillo: no se pueden
            modificar mas de un valor RGB entre cada color y el siguiente.
  */
  

  ciclo = 1;    //Empezamos en 1 para que el 0 sea en valor anterior (si empezamos en 0 da error)
  
  do {
    //Mandamos el mensaje del puerto serie dl valor de las variables y del color que toca
    Serial.print(" rojo=");
    Serial.print(led_rojo[ciclo]);
    Serial.print(" verde=");
    Serial.print(led_verde[ciclo]);
    Serial.print(" azul=");
    Serial.print(led_azul[ciclo]);
    Serial.print(" : ");
    Serial.println(color[ciclo]);


    //Codigo que comprueba si ha habido cambio en el valor a monstrar en el rojo y mira
    //si tiene que apagar o encender el rojo
    if(led_rojo[ciclo] != led_rojo[ciclo-1]) {
      if(led_rojo[ciclo]) {
        for (int a=0 ; a <=255 ; a++) {
          analogWrite(pin_R,a);
          delay(rapidez);
        }
      }
      else {
        for (int a=255 ; a >= 0 ; a--) {
          analogWrite(pin_R,a);
          delay(rapidez);
        }
      }
    }


    //Codigo que comprueba si ha habido cambio en el valor a monstrar en el verde y mira
    //si tiene que apagar o encender el verde
    if(led_verde[ciclo] != led_verde[ciclo-1]) {
      if(led_verde[ciclo]) {
        for (int a=0 ; a <=255 ; a++) {
          analogWrite(pin_G,a);
          delay(rapidez);
        }
      }
      else {
        for (int a=255 ; a >= 0 ; a--) {
          analogWrite(pin_G,a);
          delay(rapidez);
        }
      }
    }


    //Codigo que comprueba si ha habido cambio en el valor a monstrar en el azul y mira
    //si tiene que apagar o encender el azul
    if(led_azul[ciclo] != led_azul[ciclo-1]) {
      if(led_azul[ciclo]) {
        for (int a=0 ; a <=255 ; a++) {
          analogWrite(pin_B,a);
          delay(rapidez);
        }
      }
      else {
        for (int a=255 ; a >= 0 ; a--) {
          analogWrite(pin_B,a);
          delay(rapidez);
        }
      }
    }


    //codigo que solo se ejecuta si todos los valores de RGB son 0, o sea, tenemos que
    //mostrar un negro y para que delay sea igual que con los bucles IF, multiplicamos
    //el valor rapidez (usado en los bucles IF) por las 255 veces que se ejecuta. Asi
    //el tiempo que se muestra el negro es correcto (igual que los colores)
    if (led_rojo[ciclo] == 0 && led_verde[ciclo] == 0 && led_azul[ciclo] == 0) {
      delay(255*rapidez);
    }
    
    ciclo++;              //Aumentamos el valor de "ciclo" para el siguiente color
  } while (ciclo < 11);   //bucle WHILE y su condicion de repeticion. Cuando el ciclo
                          //supere la 11ª vez sale del bucle
}
